mednsktest
==========
https://github.com/idlesign/mednsktest


.. image:: https://pypip.in/d/mednsktest/badge.png
        :target: https://crate.io/packages/mednsktest



Что это
-------

*Тесты с курсов НГМУ. Консольное приложение.*

При помощи этого приложения можно готовиться к тестам, являющимся частью программ обучения медработников,
проводящимся на базе Новосибирского Госудраственного Медицинского Университета.


В комплекте следующие наборы тестов:

1. Ультразвуковая диагностика.
   
   Тесты 2013 года.

   Подтверждённая актуальность: январь 2014.

   Имя вопросника: 201401_uzd

2. Актуальные вопросы акушерства и гинекологии.

   Тесты 2012 года.

   Подтверждённая актуальность: февраль 2014.

   Имя вопросника: 201402_gyne



Как запустить
-------------

Приложение запускается из консоли при помощи команды::

    mednsktest <имя_вопросника>


Например, запускаем вопросник по УЗИ::

    mednsktest 201401_uzd


По умолчанию выдаются 50 вопросов, выбранных случаным образом из общего количества, в случайном порядке.

Количество вопросов можно ограничить при помощи ключа ``--questions_limit``.

Помощь по ключам, которые принимает приложение, можно получить так::

    mednsktest --help



Дополнительная информация
-------------------------

Файлы с тестами - обычные текстовые файлы, которые можно распечатать. Хранятся они в директории с приложением.

Приложение умеет разбирать тесты из файлов, если текст в них отформатирован следующим образом::

  #Вопрос 2
  Ультразвук - это звук, частота которого не ниже:
  #Варианты к вопросу 2
  № 1. 15 кГц;
  № 2. 20000 Гц;
  № 3. 1 МГц;
  № 4. 30 Гц;
  № 5. 20 Гц.
  #Ответ 2


Или так (правильный вариант ответа помечен `*****`)::

  #Вопрос 2
  Ультразвук - это звук, частота которого не ниже:
  #Варианты к вопросу
  № 1. 15 кГц;
  № 2. 20000 Гц; *****
  № 3. 1 МГц;
  № 4. 30 Гц;
  № 5. 20 Гц.
  #Ответ 0
